scRutiNy of single-cell RNA-seq data
====================================

``scRutiNy`` is a Python package for simulating and analyzing single-cell RNA-sequencing data.

Quick Start:
    - Install ``scRutiNy``:

    .. code-block:: sh

        pip install RNAscrutiny

    - Load ``scRutiNy`` in your Python script:

    .. code-block:: python

        import RNAscrutiny as scrutiny

    - Work through the :ref:`tutorial`, and look at some :ref:`examples` of how to use ``scRutiNy``.

Links
-----

Online documentation:
    http://lbm.niddk.nih.gov/mckennajp/scRutiNy

Python package index:
    https://pypi.python.org/pypi/RNAscrutiny

Source code repository:
    https://github.com/joepatmckenna/scRutiNy

License:
    MIT -- see the file ``LICENSE`` for details.


